@@ -1,7 +1,9 @@
 import os
 
 __all__ = ['DEFAULT_PROTOCOL',
-           'DESIGNER_ONLINE'
+           'DESIGNER_ONLINE',
+           'STYLESHEET',
+           'STYLESHEET_INCLUDE_DEFAULT'
            ]
 
 
@@ -11,3 +13,7 @@ if DEFAULT_PROTOCOL is not None:
     DEFAULT_PROTOCOL = DEFAULT_PROTOCOL.split("://")[0]
 
 DESIGNER_ONLINE = os.getenv("PYDM_DESIGNER_ONLINE", None) is not None
+
+STYLESHEET = os.getenv("PYDM_STYLESHEET", None)
+
+STYLESHEET_INCLUDE_DEFAULT = os.getenv("PYDM_STYLESHEET_INCLUDE_DEFAULT", False)
