@@ -658,6 +658,12 @@ class PyDMWidget(PyDMPrimitiveWidget):
                 self.show_address_tooltip(event)
                 return True
         return False
+    
+    def get_address(self):
+        if not len(self._channels):
+            logger.warning("Object %r has no PyDM Channels", self)
+            return
+        return self.channels()[0].address
 
     def show_address_tooltip(self, event):
         """
@@ -667,10 +673,9 @@ class PyDMWidget(PyDMPrimitiveWidget):
         EDM. If the QWidget does not have a valid PyDMChannel nothing will be
         displayed
         """
-        if not len(self._channels):
-            logger.warning("Object %r has no PyDM Channels", self)
+        addr = self.get_address()
+        if not addr:
             return
-        addr = self.channels()[0].address
         QToolTip.showText(event.globalPos(), addr)
         # If the address has a protocol, strip it out before putting it on the
         # clipboard.
@@ -959,6 +964,8 @@ class PyDMWidget(PyDMPrimitiveWidget):
             if tooltip != '':
                 tooltip += '\n'
             tooltip += "PV is disconnected."
+            tooltip += '\n'
+            tooltip +=  self.get_address()
 
         self.setToolTip(tooltip)
         self.setEnabled(status)
@@ -1104,6 +1111,8 @@ class PyDMWritableWidget(PyDMWidget):
             if tooltip != '':
                 tooltip += '\n'
             tooltip += "PV is disconnected."
+            tooltip += '\n'
+            tooltip += self.get_address()
         elif not self._write_access:
             if tooltip != '':
                 tooltip += '\n'
